# Generated by roxygen2: do not edit by hand

export(authordown)
export(authordown_read_local)
export(authordown_template)
export(authordown_validate)
export(generate_acknowledgement)
export(generate_conflict)
export(generate_contribution)
export(generate_template)
export(generate_title_page)
export(render_section_html)
