## ----echo=FALSE, results='asis'-----------------------------------------------
# During `R CMD check`, vignette code is also run by sourcing a tangled `.R`
# script, where `knitr::current_input()` is not set.
path <- "README.zh.md"
if (!file.exists(path)) {
  path <- file.path("vignettes", "README.zh.md")
}
lines <- readLines(path, warn = FALSE)
lines <- lines[!grepl("R-CMD-check", lines)]
cat(lines, sep = "\n")

